.. image:: https://github.com/amanchokshi/EMBERS/raw/master/docs/_static/imgs/embers.gif
    :width: 100%
    :align: center
    :target: https://embers.readthedocs.io/
    :alt: EMBERS logo

*Experimental Measurement of BEam Responses with Satellites*
============================================================
|PyPI| |ReadTheDocs|

*EMBERS* is a pure-Python astronomy software package designed to enable polarised measurements of radio telescope antenna beam-patterns using satellites.

*EMBERS* is designed to install cleanly with a single invocation of the standard Python package tool::

    $ pip install embers

Here are the essential project links:

* `Home page and documentation <https://embers.readthedocs.io/en/latest/>`_

* `Installing Embers <https://embers.readthedocs.io/en/latest/installation.html>`_

* `Embers by Example <https://embers.readthedocs.io/en/latest/embersbyexample.html>`_

* `Embers package <https://pypi.org/project/embers/>`_ on the Python Package Index

* `Issue tracker <https://github.com/amanchokshi/EMBERS/issues>`_ on GitHub

.. |ReadTheDocs| image:: https://readthedocs.org/projects/embers/badge/?version=latest
    :target: https://embers.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. |PyPI| image:: https://badge.fury.io/py/embers.svg
    :target: https://badge.fury.io/py/embers
